@@ -390,8 +390,9 @@ sub test_serialize : Test(9) {
 sub test_namespaces : Test(6) {
     my $self = shift;
 
-    my $cache0 =
-      do { package Foo::Bar; $self->new_cache() }; ## no critic (ProhibitMultiplePackages)
+    # Conceal package name from PAUSE indexer
+    my $package = join( "::", "Foo", "Bar" );
+    my $cache0 = eval "package $package; \$self->new_cache()";    ## no critic
     is( $cache0->namespace, 'Foo::Bar', 'namespace defaults to package' );
 
     my ( $ns1, $ns2, $ns3 ) = ( 'ns1', 'ns2', 'ns3' );
